if (FALSE) { # interactive() && curl::has_internet()
# Lookup the ID of any discipline involving the partial word "stat"
disciplines("stat")
# Use a regular expression to only exactly match the whole word Statistics and nothing else
disciplines("^statistics$")
# Use the above to search only for statisticians with the first name Louis
search_id(given = "Louis", discipline = disciplines("^statistics$")$id)
}
Run the code above in your browser using DataLab