# First, you need to use search_id() to find the mathematician ID for the
# individual(s) you wish to plot, or visit https://mathgenealogy.org/ to look
# up in the browser.
# Don't test these as rely on internet resources that can be temporarily
# unavailable.
# \donttest{
# For example, the package author would get their own tree using
g <- get_genealogy(171971)
# Then use the plot_grviz() function to produce a full genealogical tree
plot_grviz(g)
# }
Run the code above in your browser using DataLab