# Don't test these as rely on internet resources that can be temporarily
# unavailable.
# \donttest{
# Search for the package author
search_id("Aslett", "Louis")
# You may find it easier to directly use the https://mathgenealogy.org/
# website, and extract the "id" from the URL on the page for the mathematician
# of interest.
# }
Run the code above in your browser using DataLab